//--------------------------------------------------------------------------------------------------------------------------//
// Handling Interrupts correctly
//--------------------------------------------------------------------------------------------------------------------------//

// What are Interrupts? //
// You can see them as certain parts of a programm reacting to a condition at ANY time and place your programm is currently in.
// You use them to time reads for example, or for signals, etc etc.

#include <Arduino.h>

void setup()
{
    // Initializing the timer //
    void IRAM_ATTR onTimer();

    hw_timer_t *My_timer = 0;
    My_timer = timerBegin(0, 80, true);
    timerAttachInterrupt(My_timer, &onTimer, true);
    timerAlarmWrite(My_timer, 5000, true);
    timerAlarmEnable(My_timer);

    // This is crutial and has to be in the setup.
    // You can change the frequency as to when it gets called (Check it out online), as well as the reason. 
    
    // You can attach a timer to a Pin for example as well.
    // That would look something like this:
    //
    // pinMode(SWITCH_PIN, INPUT_PULLUP);
    // attachInterrupt(digitalPinToInterrupt(SWITCH_PIN), switchChanged, CHANGE);
    // But it's not necessary if you're using Interrupts as a timer. 
}

void loop()
{

}

// Handling the function //
void IRAM_ATTR onTimer()
{
    // This function is called when the interrupt has been triggered.
    
    // Keep your operations in here as SIMPLE as possible, and as quick as possible.
    // DO NOT do heavy processing on this threat, or perform long lasting operations.
    // ^ That includes any sort of printing or writing to a file for example.
    // Also refrain from using while(1) AT ALL COSTS. Short lasting while loops are fine, but also make sure they don't take too long to break out again.
}

// That is basically it for now regarding simple interrupts.
// It's useful regarding sending data only like every 5 minutes, or every 10 milliseconds for example. Use it carefully, and happy coding. :D 